==> humhub-1.14.5.tar.gz: humhub-1.14.5/protected/humhub/modules/admin/messages/ro/base.php <==
<?php

return [
    '<strong>Warning</strong> incomplete setup!' => 'Atentie! Configurare incompletă!',
    'About' => 'Despre',
    'Admin' => 'Admin',
    'Administration' => 'Administrație',
    'Approval' => 'Aprobare',
    'Authentication' => 'Autentificare',
    'Back to overview' => 'Înapoi la prezentare generală',
    'Back to user overview' => 'Înapoi la prezentarea utilizatorului',
    'Base URL needs to begin with http:// or https://' => 'Adresa trebuie să înceapă cu http:// sau https://',
    'Basic' => 'De bază',
    'Caching' => 'Caching',
    'Cronjobs' => 'Cronjobs',
    'Default' => 'Implicit',
    'Design' => 'Design',
    'Files' => 'Fisiere',
    'Groups' => 'Grupuri',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => 'Grupuri (Notă: Grupul de administratori al acestui utilizator nu poate fi gestionat cu permisiunile dvs.)',
    'Invited by' => 'Invitat de',
    'Modules' => 'App',
    'Notifications' => 'Notificari',
    'Open documentation' => 'Deschideți documentația',
    'People' => 'Persoane',
    'Proxy' => 'Proxy',
    'Search' => 'Căutare',
    'Settings' => 'Impostatii',
    'Sign up' => 'Inregistreaza-te',
    'Spaces' => 'Spatii',
    'Statistics' => 'Statistici',
    'User not found!' => 'Utilizator negăsit!',
    'Users' => 'Utilizatori',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module</strong> Administration' => '',
    'Activate' => '',
    'Add Licence Key' => '',
    'Administrative group' => '',
    'Administrators' => '',
    'Advanced' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Configure' => '',
    'Deactivate' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'General' => '',
    'Information' => '',
    'Invalid user state: {state}' => '',
    'Invite by email' => '',
    'Invite by link' => '',
    'Logging' => '',
    'Logs' => '',
    'Mailing' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'OEmbed' => '',
    'OEmbed providers' => '',
    'Pending user registrations' => '',
    'Permissions' => '',
    'Search...' => '',
    'Self test' => '',
    'Set as default' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
    'Uninstall' => '',
    'Userprofiles' => '',
];

==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/admin/messages/ro/base.php <==
<?php

return [
    '<strong>Warning</strong> incomplete setup!' => 'Atentie! Configurare incompletă!',
    'About' => 'Despre',
    'Admin' => 'Admin',
    'Administration' => 'Administrație',
    'Approval' => 'Aprobare',
    'Authentication' => 'Autentificare',
    'Back to overview' => 'Înapoi la prezentare generală',
    'Back to user overview' => 'Înapoi la prezentarea utilizatorului',
    'Base URL needs to begin with http:// or https://' => 'Adresa trebuie să înceapă cu http:// sau https://',
    'Basic' => 'De bază',
    'Caching' => 'Caching',
    'Cronjobs' => 'Cronjobs',
    'Default' => 'Implicit',
    'Design' => 'Design',
    'Files' => 'Fisiere',
    'Groups' => 'Grupuri',
    'Groups (Note: The Administrator group of this user can\'t be managed with your permissions)' => 'Grupuri (Notă: Grupul de administratori al acestui utilizator nu poate fi gestionat cu permisiunile dvs.)',
    'Invited by' => 'Invitat de',
    'Modules' => 'App',
    'Notifications' => 'Notificari',
    'Open documentation' => 'Deschideți documentația',
    'People' => 'Persoane',
    'Proxy' => 'Proxy',
    'Settings' => 'Impostatii',
    'Sign up' => 'Inregistreaza-te',
    'Spaces' => 'Spatii',
    'Statistics' => 'Statistici',
    'User not found!' => 'Utilizator negăsit!',
    'Users' => 'Utilizatori',
    '<strong>Administration</strong> menu' => '',
    '<strong>Maintenance</strong> Mode' => '',
    '<strong>Module</strong> administration' => '',
    'Activate' => '',
    'Active Modules' => '',
    'Add more modules' => '',
    'Administrative group' => '',
    'Administrators' => '',
    'Advanced' => '',
    'Advanced settings' => '',
    'Appearance' => '',
    'Configure' => '',
    'Deactivate' => '',
    'Default group for administrators of this HumHub Installation' => '',
    'Default group for all newly registered users of the network' => '',
    'Delete all' => '',
    'Delete selected rows' => '',
    'Enable module...' => '',
    'General' => '',
    'Inactive Modules' => '',
    'Information' => '',
    'Install Updates' => '',
    'Invalid user state: {state}' => '',
    'Invite by email' => '',
    'Invite by link' => '',
    'Keep your system up-to-date and benefit from the latest improvements.' => '',
    'Logging' => '',
    'Logs' => '',
    'Mailing' => '',
    'No modules installed yet. Install some to enhance the functionality!' => '',
    'OEmbed' => '',
    'OEmbed providers' => '',
    'Pending user registrations' => '',
    'Permissions' => '',
    'Self test' => '',
    'Set as default' => '',
    'Show in Marketplace' => '',
    'The cron job for the background jobs (queue) does not seem to work properly.' => '',
    'The cron job for the regular tasks (cron) does not seem to work properly.' => '',
    'This overview shows you all installed modules and allows you to enable, disable, configure and of course uninstall them. To discover new modules, take a look into our Marketplace. Please note that deactivating or uninstalling a module will result in the loss of any content that was created with that module.' => '',
    'Uninstall' => '',
    'Updates available for {count} of your modules' => '',
    'Userprofiles' => '',
    'Version' => '',
    'Visit Marketplace' => '',
    'You do not have the permission to configure modules. Please contact the administrator for further information.' => '',
    'You do not have the permission to manage modules. Please contact the administrator for further information.' => '',
];
